# Ultramax Package

This is a simple nester package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.


package/
  dist/
  src/
    kingnest/
      __init__.py
      nest.py
  test/
  LICENSE
  pyproject.toml
  README.md